about summary refs log tree commit diff
path: root/src/test/incremental
diff options
context:
space:
mode:
authorbors <bors@rust-lang.org>2018-01-29 19:47:48 +0000
committerbors <bors@rust-lang.org>2018-01-29 19:47:48 +0000
commit90eb44a5897c39e3dff9c7e48e3973671dcd9496 (patch)
tree1212800f0d1d177b48815a15bf863498fc88f611 /src/test/incremental
parent70f7d5842f29d4900f24420b030f144d21f3c5fc (diff)
parentbba81c975d9136d2bf10413826c743d25e54d97b (diff)
downloadrust-90eb44a5897c39e3dff9c7e48e3973671dcd9496.tar.gz
rust-90eb44a5897c39e3dff9c7e48e3973671dcd9496.zip
Auto merge of #47837 - eddyb:going-places, r=nikomatsakis
Replace "lvalue" terminology with "place".

See #46425 for the previous PR (which only changed MIR-related code).

r? @nikomatsakis
Diffstat (limited to 'src/test/incremental')
-rw-r--r--src/test/incremental/hashes/unary_and_binary_exprs.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/test/incremental/hashes/unary_and_binary_exprs.rs b/src/test/incremental/hashes/unary_and_binary_exprs.rs
index 85f6ef60c5d..466690e7ca1 100644
--- a/src/test/incremental/hashes/unary_and_binary_exprs.rs
+++ b/src/test/incremental/hashes/unary_and_binary_exprs.rs
@@ -404,9 +404,9 @@ pub fn value_cast(a: u32) -> i32 {
 
 
 
 // Change l-value in assignment ------------------------------------------------
 #[cfg(cfail1)]
-pub fn lvalue() -> i32 {
+pub fn place() -> i32 {
     let mut x = 10;
     let mut y = 11;
     x = 9;
@@ -416,7 +416,7 @@ pub fn lvalue() -> i32 {
 #[cfg(not(cfail1))]
 #[rustc_clean(except="HirBody,MirOptimized,MirValidated", cfg="cfail2")]
 #[rustc_clean(cfg="cfail3")]
-pub fn lvalue() -> i32 {
+pub fn place() -> i32 {
     let mut x = 10;
     let mut y = 11;
     y = 9;
@@ -404,9 +404,9 @@ pub fn value_cast(a: u32) -> i32 {
 
 
-// Change l-value in assignment ------------------------------------------------
+// Change place in assignment --------------------------------------------------
 #[cfg(cfail1)]